/**
 * Utilities exposed from abell.
 *
 * Should have jsdoc and strong type definations
 */
import { UserConfigExport as ViteUserConfigExport } from 'vite';
import { AbellPagesGlobImport } from './internal-utils.js';
import { Route, AbellViteConfig } from '../type-utils.js';
/**
 * Wrapper on top of `defineConfig` of vite. Accepts all vite configurations.
 *
 * **Usage**
 * ```ts
 * import { defineConfig } from 'abell';
 *
 * export default defineConfig({
 *  // vite configs
 * })
 * ```
 */
export declare const defineConfig: (config: AbellViteConfig) => ViteUserConfigExport;
type AbellMakeRouteOptions = {
    ignoreUnderscoreURLs?: boolean;
};
/**
 *
 * Can be used to build routes from file-system.
 *
 * Returns the Route[] object on giving globImport object.
 *
 * @param abellPages Response of glob import. You can get it by running following-
 * ```ts
 * import { makeRoutesFromGlobImport } from 'abell'
 * const abellPages = import.meta.globEager('./src/*.abell');
 *
 * export const makeRoutes = () => {
 * return makeRoutesFromGlobImport(abellPages);
 * }
 * ```
 * @returns {Route[]}
 */
export declare const makeRoutesFromGlobImport: (abellPages: AbellPagesGlobImport, options?: AbellMakeRouteOptions) => Route[];
export {};
