/**
 * Utilities used internally in abell. Do not import anything from this file!!
 */
import { Express } from 'express';
import { AbellViteConfig } from '../type-utils.js';
export type AbellPagesGlobImport = Record<string, {
    [key: string]: any;
}>;
export declare const findIndexPath: (abellPages: AbellPagesGlobImport) => string;
export declare const getPackageJSON: () => Record<string, string>;
export declare const getAbellVersion: () => string;
export declare const ABELL_PACKAGE_ROOT: string;
export declare const NODE_MODULES_DIR: string;
export declare const normalizePath: (pathString: string) => string;
export declare const urlifyPath: (pathString: string) => string;
/**
 * Removes the folder
 * @param {String} pathToRemove path to the directory which you want to remove
 */
export declare function rmdirRecursiveSync(pathToRemove: string): void;
/**
 * Recursively creates the path
 * @param {string} pathToCreate path that you want to create
 */
export declare function createPathIfAbsent(pathToCreate: string): string[];
/**
 * Find and return any random port that is available
 */
export declare const getFreePort: () => Promise<number | undefined>;
/**
 * Listen to given port if available or look for another port
 */
export declare const listen: (app: Express, port: number) => void;
/**
 * Get URL string from filepath.
 *
 * Used in `generate` to build URLs from all the files paths
 */
export declare const getURLFromFilePath: (filePath: string, basePath: string) => string;
export declare const getFilePathFromURL: (url: string, basePath: string) => string;
export declare const getConfigPath: (cwd: string) => string;
type PathOptions = {
    configFile: string;
    command: 'generate' | 'dev';
};
export declare const getViteConfig: ({ configFile, command }: PathOptions) => Promise<AbellViteConfig>;
export declare function run(command: string, { cwd }?: {
    cwd: string;
}): Promise<1 | 0>;
export declare const getViteBuildInfo: ({ configFile, command }: PathOptions) => Promise<{
    SOURCE_ENTRY_BUILD_PATH: string;
    OUT_ENTRY_BUILD_PATH: string;
    TEMP_OUTPUT_DIR: string;
    ASSETS_DIR: string;
    DEFAULT_ENTRY_BUILD_PATH: string;
    ROOT: string;
    OUTPUT_DIR: string;
    viteConfigObj: AbellViteConfig;
}>;
export declare function clearCache(): Promise<void>;
export declare const addCSSToHead: (htmlContent: string, cssLinks: string) => string;
export declare const addJStoBodyEnd: (htmlContent: string, jsLinks: string) => string;
/**
 * Evaluates the abell block.
 *
 * Internally used to clean the output and return correct value.
 *
 */
export declare const evaluateAbellBlock: (val: unknown) => string | boolean | number;
export {};
